% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stability_functions_corrected.R
\encoding{UTF-8}
\name{stabilityLustgarten}
\alias{stabilityLustgarten}
\title{Stability Measure Lustgarten}
\usage{
stabilityLustgarten(features, p, impute.na = NULL)
}
\arguments{
\item{features}{\code{list (length >= 2)}\cr
Chosen features per dataset. Each element of the list contains the features for one dataset.
The features must be given by their names (\code{character}) or indices (\code{integerish}).}

\item{p}{\code{numeric(1)}\cr
Total number of features in the datasets.}

\item{impute.na}{\code{numeric(1)}\cr
In some scenarios, the stability cannot be assessed based on all feature sets.
E.g. if some of the feature sets are empty, the respective pairwise comparisons yield NA as result.
With which value should these missing values be imputed? \code{NULL} means no imputation.}
}
\value{
\code{numeric(1)} Stability value.
}
\description{
The stability of feature selection is defined as the robustness of
the sets of selected features with respect to small variations in the data on which the
feature selection is conducted. To quantify stability, several datasets from the
same data generating process can be used. Alternatively, a single dataset can be
split into parts by resampling. Either way, all datasets used for feature selection must
contain exactly the same features. The feature selection method of interest is
applied on all of the datasets and the sets of chosen features are recorded.
The stability of the feature selection is assessed based on the sets of chosen features
using stability measures.
}
\details{
The stability measure is defined as (see Notation)
\deqn{\frac{2}{m (m - 1)} \sum_{i=1}^{m-1} \sum_{j = i+1}^m
\frac{|V_i \cap V_j| - \frac{|V_i| \cdot |V_j|}{p}}
{\min \{|V_i|, |V_j|\} - \max \{ 0, |V_i| + |V_j| - p \}}.}
}
\section{Notation}{
 For the definition of all stability measures in this package,
the following notation is used:
Let \eqn{V_1, \ldots, V_m} denote the sets of chosen features
for the \eqn{m} datasets, i.e. \code{features} has length \eqn{m} and
\eqn{V_i} is a set which contains the \eqn{i}-th entry of \code{features}.
Furthermore, let \eqn{h_j} denote the number of sets that contain feature
\eqn{X_j} so that \eqn{h_j} is the absolute frequency with which feature \eqn{X_j}
is chosen.
Also, let \eqn{q = \sum_{j=1}^p h_j}, \eqn{V = \bigcup_{i=1}^m V_i} and
\eqn{k = \frac{1}{m} \sum_{i=1}^m |V_i|}.
}

\examples{
feats = list(1:3, 1:4, 1:5)
stabilityLustgarten(features = feats, p = 10)
}
\references{
\itemize{
\item J. L. Lustgarten, V. Gopalakrishnan, and S. Visweswaran,
"Measuring stability of feature selection in biomedical datasets",
AMIA Annual Symposium proceedings/AMIA Symposium.
AMIA Symposium, vol. 2009, pp. 406-410, 2009.
\item A. Bommert, J. Rahnenführer, and M. Lang,
"A multi-criteria approach to find predictive and sparse models with
stable feature selection for high-dimensional data",
Computational and mathematical methods in medicine, 2017.
}
}
\seealso{
\link{listStabilityMeasures}
}
